OpenFlexure Motor Controller
============================
This aims to be a super-simple motor controller, based on an Arduino Nano and a couple of Darlington pair ICs.  It controls cheap 28BYJ-48 steppers, as used on the OpenFlexure microscope and stage.  It owes quite a bit to [Fergus Riche's motor board](https://github.com/fr293/motor_board), the hardware developed by [OpenScope](http://2015.igem.org/Team:Cambridge-JIC) and the Arduino-based motor controller used by a number of summer students working with Richard Bowman in Cambridge, particularly James Sharkey.

Firmware/Python code by Richard Bowman, University of Bath, PCB design & production by Sanga Valerian, STICLab.

(c) The authors, 2017, released under CERN Open Hardware License (hardware designs) and GNU GPL v3.0 (software) 2017.
